@@ -41,36 +41,87 @@ class MyWhatify:
         cls.login(email=username, password=password)
 
     @classmethod
-    def login(cls, email, password, user_id: str = None):
+    def login(cls, email, password, user_id: str = None, imp_email: str = None):
+        """
+        login to Whatify system
+
+        :param email: the user email
+        :param password: the user password
+        :param user_id: user ID to do impersonate
+        :param imp_email: user email to do impersonate
+        """
         with allure.step('login with user: ' + str(email)):
             logging.info('login with user: ' + str(email))  # + ' and password: ' + password)
             my_toolkit.UserManagement.login(email=email, password=password)
-            if user_id:
+            if imp_email:
+                with allure.step('getting user ID from email'):
+                    user_id = cls.get_user_id(imp_email)
+            if user_id and user_id != -1:
                 with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
                     my_toolkit.UserManagement.impersonate(user_id=user_id)
             cls.user_token = UserToken(my_toolkit.token)
 
     @classmethod
     def get_user_id(cls, email: str = None):
+        """
+        get the user ID of email - works only for Admin users
+
+        :param email: user email to return the ID
+
+        :return: user ID or -1 if not exist
+        """
         user_id = -1
         with allure.step('get user ID for current user or for user: ' + str(email)):
             logging.info('get user ID for current user or for user: ' + str(email))
             if email:
-                # my_toolkit.UserManagement.get_user_list(email=email)
-                user_id = -1
-                raise Exception('Need to implement')
+                user = my_toolkit.UserManagement.get_user_list(username=email)
+                if user:
+                    user_id = user['user_id']
             else:
                 user_id = cls.user_token.get_user_id()
-
         return user_id
 
     @classmethod
-    def impersonate(cls, user_id, email: str = None, admin_token: str = None):
+    def get_account_id(cls, email: str = None):
+        """
+        get the account ID of account name\email - works only for Admin users
+
+        :param email: account name\email to return the ID
+
+        :return: account ID or -1 if not exist
+        """
+        account_id = -1
+        with allure.step('get account ID for current user or for user: ' + str(email)):
+            logging.info('get account ID for current user or for user: ' + str(email))
+            if email:
+                account = my_toolkit.UserManagement.get_account_list(name=email)
+                if account:
+                    account_id = account['id']
+        return account_id
+
+    @classmethod
+    def impersonate(cls, user_id=None, email: str = None, admin_token: str = None):
+        """
+        doing impersonate for user ID or email - only works for admin users
+
+        :param user_id: the user ID to do impersonate
+        :param email: the user email to do impersonate
+        :param admin_token: the admin token to do impersonate
+        """
         with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
             my_toolkit.UserManagement.impersonate(email=email, user_id=user_id, admin_token=admin_token)
 
+    #############################
+    #######    API's      #######
+    #############################
     @classmethod
     def mark_ensemble_in_production(cls, ensemble_id, mark_production=True):
+        """
+        mark ensemble ID as in production and vice versa
+        
+        :param ensemble_id: the ensemble ID to change
+        :param mark_production: True - mark as in production, False - mark as not in production
+        """
         with allure.step('setting ensemble_id: ' + str(ensemble_id) + ' as in production: ' + str(mark_production)):
             logging.info('setting ensemble_id: ' + str(ensemble_id) + ' as in production: ' + str(mark_production))
             if mark_production:
